pub struct PythonEmitter;Expand description
Python package emitter with feature-selected legacy and ordered evidence ledgers.
Implementations
Sourceimpl PythonEmitter
impl PythonEmitter
Sourcepub fn generator_handlers(&self) -> Vec<ProjectionHandler>
pub fn generator_handlers(&self) -> Vec<ProjectionHandler>
Return its exact legacy unordered projection-handler evidence.
Sourcepub fn generator_handlers_for(
&self,
schema: &ResolvedSchema,
) -> Vec<ProjectionHandler>
pub fn generator_handlers_for( &self, schema: &ResolvedSchema, ) -> Vec<ProjectionHandler>
Return projection-handler evidence selected for the resolved schema features.
Sourcepub fn code_resources(&self) -> Result<Vec<CodeResourceDigest>, Diagnostic>
pub fn code_resources(&self) -> Result<Vec<CodeResourceDigest>, Diagnostic>
Hash its exact legacy unordered fixed output resources.
Sourcepub fn code_resources_for(
&self,
schema: &ResolvedSchema,
) -> Result<Vec<CodeResourceDigest>, Diagnostic>
pub fn code_resources_for( &self, schema: &ResolvedSchema, ) -> Result<Vec<CodeResourceDigest>, Diagnostic>
Hash the exact fixed output resources selected for the resolved schema features.
Sourcepub fn emit(
&self,
projection: &RuntimeProjection,
authority: &VerifiedSchemaAuthority,
) -> Result<GeneratedPackage, Diagnostic>
pub fn emit( &self, projection: &RuntimeProjection, authority: &VerifiedSchemaAuthority, ) -> Result<GeneratedPackage, Diagnostic>
Emit one deterministic package bound to exact verified schema authority.