TypeScriptEmitter

Struct TypeScriptEmitter 

pub struct TypeScriptEmitter;
TypeScript emitter with feature-selected legacy and ordered evidence ledgers.

Implementations

Source

impl TypeScriptEmitter

pub const fn new() -> Self

Construct the emitter.

pub fn generator_handlers(&self) -> Vec<ProjectionHandler>

Return its exact legacy unordered projection-handler evidence.

pub fn generator_handlers_for( &self, schema: &ResolvedSchema, ) -> Vec<ProjectionHandler>

Return projection-handler evidence selected for the resolved schema features.

pub fn code_resources(&self) -> Result<Vec<CodeResourceDigest>, Diagnostic>

Hash every legacy unordered fixed byte resource consumed by emission.

pub fn code_resources_for( &self, schema: &ResolvedSchema, ) -> Result<Vec<CodeResourceDigest>, Diagnostic>

Hash every fixed byte resource selected for the resolved schema features.

pub fn emit( &self, projection: &RuntimeProjection, authority: &VerifiedSchemaAuthority, ) -> Result<GeneratedPackage, Diagnostic>

Emit one deterministic ESM package bound to exact verified schema authority.